data "aws_caller_identity" "current" {}

// Generate an IAM policy document that allows access to specific resources in the AWS environment (ref:1)
data "aws_iam_policy_document" "terraform_boundary_controller" {
  statement {
    effect    = "Allow"
    resources = ["*"]
    actions = [
      "ssm:DescribeParameters",
      "ssm:ListTagsForResource",
    ]
  }
  statement {
    effect    = "Allow"
    resources = ["arn:aws:ssm:${var.aws_region}:${data.aws_caller_identity.current.account_id}:parameter/${var.namespace}/*"]
    actions = [
      "ssm:GetParameter",
      "ssm:GetParameters",
      "ssm:ListTagsForResource",
    ]
  }
  statement {
    effect    = "Allow"
    resources = ["arn:aws:ssm:${var.aws_region}:${data.aws_caller_identity.current.account_id}:parameter/???-*/*"]
    actions = [
      "ssm:GetParameter",
      "ssm:GetParameters",
      "ssm:ListTagsForResource",
    ]
  }
}

// Create an IAM policy called terraform_boundary_controller in the AWS infrastructure
// The one defined in (ref:1) is used as the policy document
resource "aws_iam_policy" "terraform_boundary_controller" {
  name   = "${var.namespace}_boundary_controller"
  policy = data.aws_iam_policy_document.terraform_boundary_controller.json
}

data "aws_iam_policy_document" "vault_assume_role" {
  statement {
    effect = "Allow"

    principals {
      type        = "AWS"
      identifiers = [var.aws_iam_user_vault_arn]
    }

    actions = ["sts:AssumeRole"]
  }
}

resource "aws_iam_role" "terraform_boundary_controller" {
  name               = "boundary-controller-${var.namespace}"
  path               = "/"
  assume_role_policy = data.aws_iam_policy_document.vault_assume_role.json
  tags = merge(local.tags, {
    "Component" : "sec",
    "Name" : "${var.environment_name}.${var.resource_group}.sec.boundary-controller-iam-role-caller-identity%{if var.n != 0}.${format("%02d", var.n)}%{endif}"
  })
}

// Create an association between the iam vault role (specified in the aws_iam_role.vault.name variable)
// and the IAM policy defined in the resource (ref:1)
resource "aws_iam_role_policy_attachment" "terraform_boundary_controller" {
  role       = aws_iam_role.terraform_boundary_controller.name
  policy_arn = aws_iam_policy.terraform_boundary_controller.arn
}
