{
  description = "Terraform";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-23.05";
    pre-commit-hooks = {
      url = "github:cachix/pre-commit-hooks.nix";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    neovim-flake = {
      url = "github:jordanisaacs/neovim-flake";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    flake-utils.url = "github:numtide/flake-utils";
  };

  outputs = inputs: with inputs; flake-utils.lib.eachDefaultSystem (system:
    let
      pkgs = import nixpkgs {
        inherit system;
      };
      terraform = pkgs.terraform.withPlugins (p: [
        p.vault
        p.gitlab
      ]);
      neovimConfig = {
        config.vim.theme.enable = true;
        config.vim.theme.name = "catppuccin";
        config.vim.startPlugins = with pkgs.vimPlugins; [
          copilot-vim
          ctrlp
          supertab
          vim-nix
          vim-terraform
          syntastic
          vim-terraform-completion
        ];
      };
      neovim = (neovim-flake.lib.neovimConfiguration {
        modules = [ neovimConfig ];
        inherit pkgs;
      });
    in
    {
      checks = {
        pre-commit-check = pre-commit-hooks.lib.${system}.run {
          src = ./.;
          hooks = {
            nixpkgs-fmt.enable = true;
            terraform-format.enable = true;
          };
        };
      };
      devShells.default = pkgs.mkShell {
        nativeBuildInputs = with pkgs; [
          curl
          convco
          git
          infracost
          jq
          just
          less
          kubectl
          man
          ncurses
          nix
          openssh
          procps
          vault
          neovim
          which
          terraform
        ];
        shellHook = ''
          ${self.checks.${system}.pre-commit-check.shellHook}
          if [ -n "$IN_NIX_SHELL" ]; then
            unset SOURCE_DATE_EPOCH
          fi
          export EDITOR=${pkgs.vim}/bin/vim
          export GIT_SSL_CAINFO=/etc/ssl/certs/ca-certificates.crt
          export LC_ALL=C
          export LIBCLANG_PATH=${pkgs.libclang.lib}/lib
          export NIX_SSL_CERT_FILE=/etc/ssl/certs/ca-certificates.crt
          export SSL_CERT_FILE=/etc/ssl/certs/ca-certificates.crt
        '';
      };
      devShells.gitlab-ci = pkgs.mkShell {
        nativeBuildInputs = with pkgs; [
          awscli2
          curl
          git
          infracost
          jq
          just
          boundary
          vault
          terraform
        ];
        shellHook = ''
          if [ -n "$IN_NIX_SHELL" ]; then
            unset SOURCE_DATE_EPOCH
          fi
          export LC_ALL=C
          export GIT_SSL_CAINFO=${cacert}/etc/ssl/certs/ca-certificates.crt
          export NIX_SSL_CERT_FILE=${cacert}/etc/ssl/certs/ca-certificates.crt
          export SSL_CERT_FILE=${cacert}/etc/ssl/certs/ca-certificates.crt
        '';
      };
    }
  );
}
